import { isOn, set } from 'feature-toggle-service';
import { Directive, Input, TemplateRef, ViewContainerRef, Component, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FeatureToggleDirective {
    /**
     * @param {?} templateRef
     * @param {?} viewContainer
     */
    constructor(templateRef, viewContainer) {
        this.templateRef = templateRef;
        this.viewContainer = viewContainer;
        this.isOn = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!this.featureToggle) {
            throw new Error('Attribute `featureToggle` should not be null or empty');
        }
        this.shouldRender();
    }
    /**
     * @return {?}
     */
    ngDoCheck() {
        if (this.isOn !== isOn(this.featureToggle)) {
            this.shouldRender();
        }
    }
    /**
     * @private
     * @return {?}
     */
    shouldRender() {
        this.isOn = isOn(this.featureToggle);
        if (this.isOn) {
            this.viewContainer.createEmbeddedView(this.templateRef);
        }
        else {
            this.viewContainer.clear();
        }
    }
}
FeatureToggleDirective.decorators = [
    { type: Directive, args: [{
                // tslint:disable-next-line: directive-selector
                selector: '[featureToggle]',
            },] }
];
/** @nocollapse */
FeatureToggleDirective.ctorParameters = () => [
    { type: TemplateRef },
    { type: ViewContainerRef }
];
FeatureToggleDirective.propDecorators = {
    featureToggle: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FeatureToggleWhenDisabledDirective {
    /**
     * @param {?} templateRef
     * @param {?} viewContainer
     */
    constructor(templateRef, viewContainer) {
        this.templateRef = templateRef;
        this.viewContainer = viewContainer;
        this.isOn = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!this.featureToggleWhenDisabled) {
            throw new Error('Attribute `featureToggleWhenDisabled` should not be null or empty');
        }
        this.shouldRender();
    }
    /**
     * @return {?}
     */
    ngDoCheck() {
        if (this.isOn !== isOn(this.featureToggleWhenDisabled)) {
            this.shouldRender();
        }
    }
    /**
     * @return {?}
     */
    shouldRender() {
        this.isOn = isOn(this.featureToggleWhenDisabled);
        if (!this.isOn) {
            this.viewContainer.createEmbeddedView(this.templateRef);
        }
        else {
            this.viewContainer.clear();
        }
    }
}
FeatureToggleWhenDisabledDirective.decorators = [
    { type: Directive, args: [{
                // tslint:disable-next-line: directive-selector
                selector: '[featureToggleWhenDisabled]',
            },] }
];
/** @nocollapse */
FeatureToggleWhenDisabledDirective.ctorParameters = () => [
    { type: TemplateRef },
    { type: ViewContainerRef }
];
FeatureToggleWhenDisabledDirective.propDecorators = {
    featureToggleWhenDisabled: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FeatureToggleProviderComponent {
    constructor() {
        this.features = {};
        this.currentConfig = {};
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (typeof this.features !== 'object') {
            throw new Error('Attribute `features` should not be null or empty');
        }
        this.setFeatureToggles();
    }
    /**
     * @return {?}
     */
    ngDoCheck() {
        this.setFeatureToggles();
    }
    /**
     * @private
     * @return {?}
     */
    setFeatureToggles() {
        if (this.currentConfig !== this.features) {
            this.currentConfig = this.features;
            set(this.features);
        }
    }
}
FeatureToggleProviderComponent.decorators = [
    { type: Component, args: [{
                selector: 'feature-toggle-provider',
                template: `
    <ng-content></ng-content>
  `
            }] }
];
FeatureToggleProviderComponent.propDecorators = {
    features: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FeatureToggleModule {
}
FeatureToggleModule.decorators = [
    { type: NgModule, args: [{
                declarations: [FeatureToggleProviderComponent, FeatureToggleDirective, FeatureToggleWhenDisabledDirective],
                exports: [FeatureToggleProviderComponent, FeatureToggleDirective, FeatureToggleWhenDisabledDirective],
                imports: [CommonModule],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { FeatureToggleDirective, FeatureToggleWhenDisabledDirective, FeatureToggleProviderComponent, FeatureToggleModule };

//# sourceMappingURL=ngx-feature-toggle.js.map